#include <stddef.h>
#include "hal/hal.h"

void *memset(void *p, int c, size_t n) {
  return hal_memset(p,c,n);
}

void *memcpy(void *dst, const void *src, size_t n) {
  return hal_memcpy(dst,src,n);
}

size_t strlen(char *s) {
  return hal_strlen(s);
}

int strcmp(const char *a, const char *b) {
  return hal_strcmp(a, b);
}

size_t strcspn(const char *s, const char *reject) {
  return hal_strcspn(s, reject);
}

size_t strspn(const char *s, const char *accept) {
  return hal_strspn(s, accept);
}


char *strcpy(char *dest, const char *src) {
  return hal_strcpy(dest, src);
}

char *strchr(const char *s, int c) {
  return hal_strchr(s, c);
}

int memcmp(const void *s1, const void *s2, int len) {
  return hal_memcmp(s1, s2, len);
}
